#
# spec file for package libmaa
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 4
Name:           libmaa
Version:        1.5.1
Release:        1.3
Summary:        Library providing many low-level data structures
License:        MIT
URL:            https://github.com/cheusov/libmaa
Source0:        https://downloads.sourceforge.net/dict/%{name}-%{version}.tar.gz
BuildRequires:  mk-configure
BuildRequires:  pkgconfig(zlib)

%description
The libmaa library provides many low-level data structures which can
be used for writing compilers, hash tables, sets, lists,
debugging support, and memory management. libmaa was originally
implemented as a foundation for the "kheperalong" package.

%package -n %{name}%{soname}
Summary:        Library providing many low-level data structures
Group:          System/Libraries

%description -n %{name}%{soname}
The libmaa library provides many low-level data structures which can
be used for writing compilers, hash tables, sets, lists,
debugging support, and memory management. libmaa was originally
implemented as a foundation for the "kheperalong" package.

%package -n %{name}-devel
Summary:        Development files for libmaa
Group:          Development/Libraries/C and C++
Requires:       libmaa%{soname} = %{version}

%description -n %{name}-devel
This RPM contains the development files for libmaa.

%package doc
Summary:        Documentation files for libmaa
Group:          Documentation/Other
BuildArch:      noarch

%description doc
This RPM contains the documentation files for libmaa.

%prep
%autosetup

%define env \
        unset MAKEFLAGS \
        export MKSTATICLIB=no \
        export NOSUBDIR=doc

%build
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
mkc_compiler_settings
%endif
%{env}
%{mkcmake}

%install
%{env}
%{mkcmake} install DESTDIR=%{?buildroot}

%post -n %{name}%{soname} -p /sbin/ldconfig
%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%license doc/LICENSE
%doc README doc/NEWS
%{_libdir}/*.so.*

%files -n %{name}-devel
%{_includedir}/maa*
%{_libdir}/*.so

%files doc
%license doc/LICENSE
%doc doc/*.ps*

%changelog
* Sun Jun 16 2024 Aleksey Cheusov <vle@gmx.net>
- Update to version 1.5.1
  * Improve tests/pr test
  * Add new function pr_open2 with argument "callback" ran from
    child process immediately after fork(2) and before execvp(3).
  * COPTS defaults to -O2 -g
  * Add support for target "help", bump MKC_REQD to 0.34.0
  * maa/log.c: fix compilation failure due to -Werror on
    NetBSD-10.99.10 with gcc-10.5.0
  * Move WARNS=4 to Makefile.common
  * SUBPRJ_DFLT = maa test
  * MAXHOSTNAMELEN can be already defined, limit to 64 characters
    to avoid possible truncation.
* Mon Apr 13 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 1.4.7
  * Fix incorrect work of set_* where hash function generates
    full ulong_t hash value
  * hsh_string_hash generates full 64bit hash value on platforms
    where sizeof(long) == 8
  * Improve build and test system
  * tests/err: minor fix, target "test" should not remove _mkc_*
    and .o files
  * Avoid trailing \n in format argument for err_* functions, no
    need for it any longer
  * tests/err/errtest.c: fix another compilation failure due to
    __wur (warning used result)
  version 1.4.6
  * Add missing fix (compilation failure) for tests/err/errtest.c
  version 1.4.5
  * err_* functions:
    + Fix segfault caused by "ap" is used twice.  Solution is to
    va_copy it and use copied "ap" for printing to stderr.
    + Improve formatting (no empty lines in log files)
  * err_set_program_name: handle correctly NULL argument
  * log_mkpath function: avoid use of alloca(3)
  * hsh_pointer_compare function now follows -1/0/1 logic
  * Add more tests for log_*, err_*, hsh_* and set_* function
- Fix build with gcc 9.x
- Drop Group tag
- Spec cleanup
* Tue Apr 23 2019 vle@gmx.net
- Update to libmaa-1.4.4:
  * Fix compilation failure using gcc-8
- Simplify build process using capabilities of mk-configure
- Remove patches already applied in upstream, specifically
  - 02-Spelling-typos.patch
  - 03-Fix-gcc-8-ftbfs.patch
- Fix License in rpm spec
- Remove unnecessary dependencies from rpm spec
* Thu Mar  7 2019 Matej Cepl <mcepl@suse.com>
- Update to 1.4.3:
  - Fix parallel build
  - Explicitely enable WARNERR and remove gcc-ism from CFLAGS
* Mon Jan 28 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from descriptions. Set proper RPM groups,
  and noarch status for doc subpackage.
- Drop silly glibc PreReq.
* Sat Jan 26 2019 mcepl@suse.com
- Upgrade to libmaa-1.4.2:
  * Fix build failure on SunOS-5.11 (alloca)
  * License has been changed from LGPL to MIT, permitted by Rik
    Faith, original author of this library.
  * Build system changed from autotools to mk-configure.
  * Library version/soname was bumped from 3 to 4. I cannot
    guarantee that mk-configure and libtool build shared library
    the same way.
  * Tests were added for stk_*, mem_* and prm_* functions.
  * stk_isempty function was added.
  * stk_* and other was reimplemented without obstack functions
    (glibc extension).
* Tue Oct  9 2018 mcepl@suse.com
- Add 02-Spelling-typos.patch and 03-Fix-gcc-8-ftbfs.patch from Debian
  package.
* Sun Nov 27 2011 brunciter@localhost.lan
- initial package
